@@ -1,16 +1,18 @@
 """Module to build overlay graphs for network design"""
-import autonetkit
-import autonetkit.anm
-import autonetkit.ank_messaging as ank_messaging
-import autonetkit.config
-SETTINGS = autonetkit.config.settings
-import autonetkit.log as log
-import autonetkit.load.graphml as graphml
-import autonetkit.exception
-import networkx as nx
-import autonetkit.ank as ank_utils
 import itertools
 
+import autonetkit
+import autonetkit.ank as ank_utils
+import autonetkit.ank_messaging as ank_messaging
+import autonetkit.anm
+import autonetkit.config
+import autonetkit.exception
+import autonetkit.load.graphml as graphml
+import autonetkit.log as log
+import networkx as nx
+
+SETTINGS = autonetkit.config.settings
+
 #TODO: revisit phy_neighbors for eg ASN and use l3_conn instead
 
 #TODO: remove retain edge_id once removed from compiler
@@ -230,9 +232,15 @@ def apply_design_rules(anm):
 
 def build(input_graph):
     """Main function to build network overlay topologies"""
-    anm = initialise(input_graph)
-    anm = apply_design_rules(anm)
-    #autonetkit.update_http(anm)
+    try:
+        anm = initialise(input_graph)
+        anm = apply_design_rules(anm)
+        #print {str(node): {'x': node.x, 'y': node.y} for node in anm['input']}
+    except Exception, e:
+        # Send the visualisation to help debugging
+            import autonetkit
+            autonetkit.update_http(anm)
+            raise e
     return anm
 
 def vrf_pre_process(anm):
@@ -543,6 +551,3 @@ def build_conn(anm):
     g_conn.add_edges_from(g_in.edges(type="physical"))
 
     return
-
-
-
