@@ -1,19 +1,21 @@
 """Console script entry point for AutoNetkit"""
 
-from autonetkit.nidb import NIDB
-import autonetkit.render as render
+import os
 import random
-from autonetkit import update_http
+import sys
+import time
 import traceback
 from datetime import datetime
-import os
-import time
-import autonetkit.compiler as compiler
-import pkg_resources
-import autonetkit.log as log
-import autonetkit.ank_messaging as ank_messaging
-import autonetkit.config as config
+
 import autonetkit.ank_json as ank_json
+import autonetkit.ank_messaging as ank_messaging
+import autonetkit.compiler as compiler
+import autonetkit.config as config
+import autonetkit.log as log
+import autonetkit.render as render
+import pkg_resources
+from autonetkit import update_http
+from autonetkit.nidb import NIDB
 
 # TODO: make if measure set, then not compile - or warn if both set, as
 # don't want to regen topology when measuring
@@ -54,7 +56,10 @@ def manage_network(input_graph_string, timestamp, build_options, reload_build=Fa
 
         if build_options['validate']:
             import autonetkit.ank_validate
-            autonetkit.ank_validate.validate(anm)
+            try:
+                autonetkit.ank_validate.validate(anm)
+            except Exception, e:
+                log.warning("Unable to validate topologies: %s" % e)
 
     if build_options['compile']:
         if build_options['archive']:
@@ -202,7 +207,13 @@ def main(options):
         log.info("No input file specified. Exiting")
         raise SystemExit
 
-    manage_network(input_string, timestamp, build_options=build_options, grid = options.grid)
+    try:
+        manage_network(input_string, timestamp, build_options=build_options, grid = options.grid)
+    except Exception, err:
+        log.error("Error generating network configurations: %s. More information may be available in the debug log." % err)
+        log.debug("Error generating network configurations", exc_info = True)
+        import sys
+        sys.exit("Unable to build configurations.")
 
 
 # TODO: work out why build_options is being clobbered for monitor mode
