@@ -1,5 +1,6 @@
-import autonetkit.log as log
 import autonetkit.ank as ank_utils
+import autonetkit.log as log
+
 
 def three_tier_ibgp_corner_cases(rtrs):
     """Calculate edges for iBGP l3 clusters that don't contain a HRR.
@@ -205,7 +206,7 @@ def build_ibgp(anm):
 
     for n in g_bgp:
         # Tag with label to make logic clearer
-        if not n.ibgp_level:
+        if n.ibgp_level is None:
             # No level set -> treat as RRC
             if (n.rr_cluster is None) and (n.hrr_cluster is None):
                 n.top_level_peer = True
@@ -437,4 +438,4 @@ def build_bgp(anm):
             interface.multipoint = any(e.multipoint for e in interface.edges())
 
     build_ibgp_v4(anm)
-    build_ibgp_v6(anm)
\ No newline at end of file
+    build_ibgp_v6(anm)
