@@ -1,11 +1,12 @@
-import networkx as nx
-import pprint
 import collections
-import time
-import autonetkit.log as log
-import ank_json
 import functools
+import pprint
 import string
+import time
+
+import ank_json
+import autonetkit.log as log
+import networkx as nx
 
 try:
     import cPickle as pickle
@@ -186,7 +187,7 @@ class overlay_interface(object):
 
     def __repr__(self):
         description = self.description or self.interface_id
-        return "(%s, %s)" % (self.node_id, description)
+        return "(%s, %s)" % (self.node, description)
 
     def __nonzero__(self):
         """Allows for checking if node exists
@@ -203,7 +204,7 @@ class overlay_interface(object):
 
     @property
     def _node(self):
-        """Return graph the node belongs to"""
+        """Return node the node belongs to"""
         return self._graph.node[self.node_id]
 
     @property
